assert_input_multivariate_sample: Assert that inputs are correct for sample-based forecast

View source: R/metrics-multivariate-sample.R

assert_input_multivariate_sampleR Documentation

Assert that inputs are correct for sample-based forecast

Description

Function assesses whether the inputs correspond to the requirements for scoring sample-based forecasts.

Usage

assert_input_multivariate_sample(observed, predicted, mv_group_id)

Arguments

observed

Input to be checked. Should be a numeric vector with the observed values of size n.

predicted

Input to be checked. Should be a numeric nxN matrix of predictive samples, n (number of rows) being the number of data points and N (number of columns) the number of samples per forecast. If observed is just a single number, then predicted values can just be a vector of size N.

mv_group_id

Numeric vector of length n with ids indicating the grouping of predicted values. Conceptually, each row of the predicted matrix could be seen as a separate (univariate) forecast. The grouping id then groups several of those forecasts together, treating them as a single multivariate forecast.

Value

Returns NULL invisibly if the assertion was successful and throws an error otherwise.


scoringutils documentation built on April 6, 2026, 1:07 a.m.