| example_multivariate_sample | R Documentation |
A data set with continuous multivariate predictions for COVID-19 cases and deaths constructed from data submitted to the European Forecast Hub.
example_multivariate_sample
An object of class forecast_multivariate_sample
(see as_forecast_multivariate_sample()) with the following columns:
the country for which a prediction was made
the date for which a prediction was made
the target to be predicted (cases or deaths)
observed values
name of the country for which a prediction was made
the date on which a prediction was made
name of the model that generated the forecasts
forecast horizon in weeks
predicted value
id for the corresponding sample
id for the corresponding group
The data was created using the script create-example-data.R in the inst/ folder (or the top level folder in a compiled package).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.