get_grouping: Get grouping for a multivariate forecast

get_groupingR Documentation

Get grouping for a multivariate forecast

Description

Helper function to get the grouping for a multivariate forecast.

Usage

get_grouping(forecast)

Arguments

forecast

A forecast object (a validated data.table with predicted and observed values).

Value

A character vector with the names of the columns that define the grouping.


scoringutils documentation built on April 6, 2026, 1:07 a.m.