View source: R/class-forecast-multivariate-point.R
| get_metrics.forecast_multivariate_point | R Documentation |
For multivariate point forecasts, the default scoring rule is:
"variogram_score" =
variogram_score_multivariate_point()
## S3 method for class 'forecast_multivariate_point'
get_metrics(x, select = NULL, exclude = NULL, ...)
x |
A forecast object (a validated data.table with predicted and
observed values, see |
select |
A character vector of scoring rules to select from the list. If
|
exclude |
A character vector of scoring rules to exclude from the list.
If |
... |
unused |
Overview of required input format for binary and point forecasts
Other get_metrics functions:
get_metrics(),
get_metrics.forecast_binary(),
get_metrics.forecast_multivariate_sample(),
get_metrics.forecast_nominal(),
get_metrics.forecast_ordinal(),
get_metrics.forecast_point(),
get_metrics.forecast_quantile(),
get_metrics.forecast_sample(),
get_metrics.scores()
data <- data.frame(
observed = c(1, 2, 3),
predicted = c(1.1, 2.2, 3.3),
target = c("a", "b", "c"),
model = "m1",
date = "2020-01-01"
)
ex <- as_forecast_multivariate_point(
data,
forecast_unit = c("model", "date", "target"),
joint_across = "target"
)
get_metrics(ex)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.