| get_metrics.forecast_multivariate_sample | R Documentation |
For sample-based multivariate forecasts, the default scoring rules are:
"energy_score" = energy_score_multivariate()
"variogram_score" = variogram_score_multivariate()
## S3 method for class 'forecast_multivariate_sample'
get_metrics(x, select = NULL, exclude = NULL, ...)
x |
A forecast object (a validated data.table with predicted and
observed values, see |
select |
A character vector of scoring rules to select from the list. If
|
exclude |
A character vector of scoring rules to exclude from the list.
If |
... |
unused |
Overview of required input format for sample-based forecasts
Other get_metrics functions:
get_metrics(),
get_metrics.forecast_binary(),
get_metrics.forecast_multivariate_point(),
get_metrics.forecast_nominal(),
get_metrics.forecast_ordinal(),
get_metrics.forecast_point(),
get_metrics.forecast_quantile(),
get_metrics.forecast_sample(),
get_metrics.scores()
example <- as_forecast_multivariate_sample(
example_sample_continuous, joint_across = c("location", "location_name")
)
get_metrics(example)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.