Learn R Programming

scoringutils (version 2.3.0)

impute_mean_score: Impute with mean observed score

Description

Strategy for impute_missing_scores() that fills each missing metric with the mean observed value for that metric within the same target combination across all values of the compare column. Target combinations with no non-NA observations are filled with NA_real_.

Usage

impute_mean_score()

Arguments

Value

A strategy function for impute_missing_scores().

See Also

impute_missing_scores(), impute_worst_score()

Examples

Run this code
# \dontshow{
  data.table::setDTthreads(2)
# }
scores <- example_quantile |>
  as_forecast_quantile() |>
  score()

impute_missing_scores(scores, strategy = impute_mean_score())

Run the code above in your browser using DataLab