Learn R Programming

scoringutils (version 2.3.0)

impute_model_score: Impute with a reference model's scores

Description

Strategy for impute_missing_scores() that fills missing scores with the scores of a specified reference model for the same target combination.

Usage

impute_model_score(model)

Value

A strategy function for impute_missing_scores().

Arguments

model

Character string naming the reference model whose scores should be used for imputation. The reference model must have scores for all target combinations that need imputing; otherwise an error is raised.

See Also

impute_missing_scores()

Examples

Run this code
# \dontshow{
  data.table::setDTthreads(2)
# }
scores <- example_quantile |>
  as_forecast_quantile() |>
  score()

impute_missing_scores(
  scores,
  strategy = impute_model_score("EuroCOVIDhub-baseline")
)

Run the code above in your browser using DataLab