plot_correlations: Plot correlation between metrics

View source: R/get-correlations.R

plot_correlationsR Documentation

Plot correlation between metrics

Description

Plots a heatmap of correlations between different metrics.

Usage

plot_correlations(correlations, digits = NULL)

Arguments

correlations

A data.table of correlations between scores as produced by get_correlations().

digits

A number indicating how many decimal places the correlations should be rounded to. By default (digits = NULL) no rounding takes place.

Value

A ggplot object showing a coloured matrix of correlations between metrics.

A ggplot object with a visualisation of correlations between metrics

Examples

scores <- example_quantile |>
  as_forecast_quantile() |>
  score()
correlations <- scores |>
  summarise_scores() |>
  get_correlations()
plot_correlations(correlations, digits = 2)

scoringutils documentation built on April 6, 2026, 1:07 a.m.