Function assesses whether the inputs correspond to the requirements for scoring sample-based forecasts.
assert_input_multivariate_sample(observed, predicted, mv_group_id)Returns NULL invisibly if the assertion was successful and throws an error otherwise.
Input to be checked. Should be a numeric vector with the observed values of size n.
Input to be checked. Should be a numeric nxN matrix of
predictive samples, n (number of rows) being the number of data points and
N (number of columns) the number of samples per forecast.
If observed is just a single number, then predicted values can just be a
vector of size N.
Numeric vector of length n with ids indicating the
grouping of predicted values. Conceptually, each row of the predicted
matrix could be seen as a separate (univariate) forecast.
The grouping id then groups several of those forecasts together, treating
them as a single multivariate forecast.