| get_grouping | R Documentation |
Helper function to get the grouping for a multivariate forecast.
get_grouping(forecast)
forecast |
A forecast object (a validated data.table with predicted and observed values). |
A character vector with the names of the columns that define the grouping.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.