Learn R Programming

scoringutils (version 2.3.0)

get_grouping: Get grouping for a multivariate forecast

Description

Helper function to get the grouping for a multivariate forecast.

Usage

get_grouping(forecast)

Value

A character vector with the names of the columns that define the grouping.

Arguments

forecast

A forecast object (a validated data.table with predicted and observed values).