powered by
Helper function to get the grouping for a multivariate forecast.
get_grouping(forecast)
A character vector with the names of the columns that define the grouping.
A forecast object (a validated data.table with predicted and observed values).