Learn R Programming

scoringutils (version 2.3.0)

get_metrics.forecast_multivariate_point: Get default metrics for multivariate point forecasts

Description

For multivariate point forecasts, the default scoring rule is:

  • "variogram_score" = variogram_score_multivariate_point()

Usage

# S3 method for forecast_multivariate_point
get_metrics(x, select = NULL, exclude = NULL, ...)

Arguments

x

A forecast object (a validated data.table with predicted and observed values, see as_forecast_binary()).

select

A character vector of scoring rules to select from the list. If select is NULL (the default), all possible scoring rules are returned.

exclude

A character vector of scoring rules to exclude from the list. If select is not NULL, this argument is ignored.

...

unused

Input format

Overview of required input format for binary and point forecasts

See Also

Other get_metrics functions: get_metrics(), get_metrics.forecast_binary(), get_metrics.forecast_multivariate_sample(), get_metrics.forecast_nominal(), get_metrics.forecast_ordinal(), get_metrics.forecast_point(), get_metrics.forecast_quantile(), get_metrics.forecast_sample(), get_metrics.scores()

Examples

Run this code
data <- data.frame(
  observed = c(1, 2, 3),
  predicted = c(1.1, 2.2, 3.3),
  target = c("a", "b", "c"),
  model = "m1",
  date = "2020-01-01"
)
ex <- as_forecast_multivariate_point(
  data,
  forecast_unit = c("model", "date", "target"),
  joint_across = "target"
)
get_metrics(ex)

Run the code above in your browser using DataLab