Learn R Programming

scoringutils (version 2.3.0)

get_metrics.forecast_multivariate_sample: Get default metrics for sample-based forecasts

Description

For sample-based multivariate forecasts, the default scoring rules are:

  • "energy_score" = energy_score_multivariate()

  • "variogram_score" = variogram_score_multivariate()

Usage

# S3 method for forecast_multivariate_sample
get_metrics(x, select = NULL, exclude = NULL, ...)

Arguments

x

A forecast object (a validated data.table with predicted and observed values, see as_forecast_binary()).

select

A character vector of scoring rules to select from the list. If select is NULL (the default), all possible scoring rules are returned.

exclude

A character vector of scoring rules to exclude from the list. If select is not NULL, this argument is ignored.

...

unused

Input format

Overview of required input format for sample-based forecasts

See Also

Other get_metrics functions: get_metrics(), get_metrics.forecast_binary(), get_metrics.forecast_multivariate_point(), get_metrics.forecast_nominal(), get_metrics.forecast_ordinal(), get_metrics.forecast_point(), get_metrics.forecast_quantile(), get_metrics.forecast_sample(), get_metrics.scores()

Examples

Run this code
example <- as_forecast_multivariate_sample(
  example_sample_continuous, joint_across = c("location", "location_name")
)
get_metrics(example)

Run the code above in your browser using DataLab