impute_mean_score: Impute with mean observed score
Description
Strategy for impute_missing_scores() that fills each
missing metric with the mean observed value for that metric
within the same target combination across all values of the
compare column. Target combinations with no non-NA
observations are filled with NA_real_.