View source: R/get-correlations.R
| plot_correlations | R Documentation |
Plots a heatmap of correlations between different metrics.
plot_correlations(correlations, digits = NULL)
correlations |
A data.table of correlations between scores as produced
by |
digits |
A number indicating how many decimal places the correlations
should be rounded to. By default ( |
A ggplot object showing a coloured matrix of correlations between metrics.
A ggplot object with a visualisation of correlations between metrics
scores <- example_quantile |>
as_forecast_quantile() |>
score()
correlations <- scores |>
summarise_scores() |>
get_correlations()
plot_correlations(correlations, digits = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.