Learn R Programming

scoringutils (version 2.3.0)

plot_correlations: Plot correlation between metrics

Description

Plots a heatmap of correlations between different metrics.

Usage

plot_correlations(correlations, digits = NULL)

Value

A ggplot object showing a coloured matrix of correlations between metrics.

A ggplot object with a visualisation of correlations between metrics

Arguments

correlations

A data.table of correlations between scores as produced by get_correlations().

digits

A number indicating how many decimal places the correlations should be rounded to. By default (digits = NULL) no rounding takes place.

Examples

Run this code
scores <- example_quantile |>
  as_forecast_quantile() |>
  score()
correlations <- scores |>
  summarise_scores() |>
  get_correlations()
plot_correlations(correlations, digits = 2)

Run the code above in your browser using DataLab