powered by
Plots a heatmap of correlations between different metrics.
plot_correlations(correlations, digits = NULL)
A ggplot object showing a coloured matrix of correlations between metrics.
A ggplot object with a visualisation of correlations between metrics
A data.table of correlations between scores as produced by get_correlations().
get_correlations()
A number indicating how many decimal places the correlations should be rounded to. By default (digits = NULL) no rounding takes place.
digits = NULL
scores <- example_quantile |> as_forecast_quantile() |> score() correlations <- scores |> summarise_scores() |> get_correlations() plot_correlations(correlations, digits = 2)
Run the code above in your browser using DataLab