Facilitate the evaluation of forecasts in a convenient framework based on data.table. It allows user to to check their forecasts and diagnose issues, to visualise forecasts and missing data, to transform data before scoring, to handle missing forecasts, to aggregate scores, and to visualise the results of the evaluation. The package mostly focuses on the evaluation of probabilistic forecasts and allows evaluating several different forecast types and input formats. Find more information about the package in the Vignettes as well as in the accompanying paper, tools:::Rd_expr_doi("10.48550/arXiv.2205.07090").
Maintainer: Nikos Bosse [email protected] (ORCID)
Authors:
Nikos Bosse [email protected] (ORCID)
Sam Abbott [email protected] (ORCID)
Hugo Gruson [email protected] (ORCID)
Sebastian Funk [email protected]
Other contributors:
Johannes Bracher [email protected] (ORCID) [contributor]
Toshiaki Asakura [email protected] (ORCID) [contributor]
James Mba Azam [email protected] (ORCID) [contributor]
Michael Chirico [email protected] (ORCID) [contributor]
Useful links:
tools:::Rd_expr_doi("10.48550/arXiv.2205.07090")
Report bugs at https://github.com/epiforecasts/scoringutils/issues