| set_grouping | R Documentation |
Helper function to set the grouping of a forecast.
set_grouping(data, joint_across)
data |
A data.frame (or similar) with predicted and observed values. See the details section of for additional information on the required input format. |
joint_across |
Character vector with columns names that define the
variables which are forecasted jointly. Conceptually, several univariate
forecasts are pooled together to form a single multivariate forecasts.
For example, if you have a column |
A data.table with an additional column .mv_group_id that
contains the group id for each row.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.