Helper function to set the grouping of a forecast.
set_grouping(data, joint_across)A data.table with an additional column .mv_group_id that
contains the group id for each row.
A data.frame (or similar) with predicted and observed values. See the "Target format" section in Details for additional information on the required input format.
Character vector with columns names that define the
variables which are forecasted jointly. Conceptually, several univariate
forecasts are pooled together to form a single multivariate forecasts.
For example, if you have a column country and want to define
a multivariate forecast for several countries at once, you could set
joint_across = "country".